# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_datatab.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_data(object):
    def setupUi(self, data):
        data.setObjectName("data")
        data.resize(761, 857)
        self.verticalLayout = QtWidgets.QVBoxLayout(data)
        self.verticalLayout.setObjectName("verticalLayout")
        self.layoutVolume = QtWidgets.QVBoxLayout()
        self.layoutVolume.setObjectName("layoutVolume")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.label_13 = QtWidgets.QLabel(data)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_6.addWidget(self.label_13)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.checkBoxLeftView = QtWidgets.QCheckBox(data)
        self.checkBoxLeftView.setText("")
        self.checkBoxLeftView.setChecked(True)
        self.checkBoxLeftView.setObjectName("checkBoxLeftView")
        self.horizontalLayout_8.addWidget(self.checkBoxLeftView)
        self.checkBoxCentralView = QtWidgets.QCheckBox(data)
        self.checkBoxCentralView.setText("")
        self.checkBoxCentralView.setChecked(True)
        self.checkBoxCentralView.setObjectName("checkBoxCentralView")
        self.horizontalLayout_8.addWidget(self.checkBoxCentralView)
        self.checkBoxRightView = QtWidgets.QCheckBox(data)
        self.checkBoxRightView.setText("")
        self.checkBoxRightView.setChecked(True)
        self.checkBoxRightView.setObjectName("checkBoxRightView")
        self.horizontalLayout_8.addWidget(self.checkBoxRightView)
        self.verticalLayout_6.addLayout(self.horizontalLayout_8)
        self.line_6 = QtWidgets.QFrame(data)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.verticalLayout_6.addWidget(self.line_6)
        self.label = QtWidgets.QLabel(data)
        self.label.setObjectName("label")
        self.verticalLayout_6.addWidget(self.label)
        self.horizontalLayoutExtraButtons = QtWidgets.QHBoxLayout()
        self.horizontalLayoutExtraButtons.setObjectName("horizontalLayoutExtraButtons")
        self.pushButtonManagerRed = QtWidgets.QPushButton(data)
        self.pushButtonManagerRed.setText("")
        self.pushButtonManagerRed.setObjectName("pushButtonManagerRed")
        self.horizontalLayoutExtraButtons.addWidget(self.pushButtonManagerRed)
        self.pushButtonManagerBlue = QtWidgets.QPushButton(data)
        self.pushButtonManagerBlue.setText("")
        self.pushButtonManagerBlue.setObjectName("pushButtonManagerBlue")
        self.horizontalLayoutExtraButtons.addWidget(self.pushButtonManagerBlue)
        self.pushButtonManagerGreen = QtWidgets.QPushButton(data)
        self.pushButtonManagerGreen.setText("")
        self.pushButtonManagerGreen.setObjectName("pushButtonManagerGreen")
        self.horizontalLayoutExtraButtons.addWidget(self.pushButtonManagerGreen)
        self.verticalLayout_6.addLayout(self.horizontalLayoutExtraButtons)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.pushButtonManagerOrange = QtWidgets.QPushButton(data)
        self.pushButtonManagerOrange.setText("")
        self.pushButtonManagerOrange.setObjectName("pushButtonManagerOrange")
        self.horizontalLayout_9.addWidget(self.pushButtonManagerOrange)
        self.pushButtonManagerGrey = QtWidgets.QPushButton(data)
        self.pushButtonManagerGrey.setText("")
        self.pushButtonManagerGrey.setObjectName("pushButtonManagerGrey")
        self.horizontalLayout_9.addWidget(self.pushButtonManagerGrey)
        self.pushButtonManagerCyan = QtWidgets.QPushButton(data)
        self.pushButtonManagerCyan.setText("")
        self.pushButtonManagerCyan.setObjectName("pushButtonManagerCyan")
        self.horizontalLayout_9.addWidget(self.pushButtonManagerCyan)
        self.verticalLayout_6.addLayout(self.horizontalLayout_9)
        self.horizontalLayout.addLayout(self.verticalLayout_6)
        self.line_7 = QtWidgets.QFrame(data)
        self.line_7.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_7.setObjectName("line_7")
        self.horizontalLayout.addWidget(self.line_7)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.checkBoxLinkViews = QtWidgets.QCheckBox(data)
        self.checkBoxLinkViews.setChecked(True)
        self.checkBoxLinkViews.setObjectName("checkBoxLinkViews")
        self.verticalLayout_7.addWidget(self.checkBoxLinkViews)
        self.checkBox6Views = QtWidgets.QCheckBox(data)
        self.checkBox6Views.setObjectName("checkBox6Views")
        self.verticalLayout_7.addWidget(self.checkBox6Views)
        self.horizontalLayout.addLayout(self.verticalLayout_7)
        self.line_8 = QtWidgets.QFrame(data)
        self.line_8.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_8.setObjectName("line_8")
        self.horizontalLayout.addWidget(self.line_8)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_2 = QtWidgets.QLabel(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_9.addWidget(self.label_2)
        self.comboBoxOrientation = QComboBoxIgnoreSCroll(data)
        self.comboBoxOrientation.setObjectName("comboBoxOrientation")
        self.comboBoxOrientation.addItem("")
        self.comboBoxOrientation.addItem("")
        self.comboBoxOrientation.addItem("")
        self.comboBoxOrientation.addItem("")
        self.verticalLayout_9.addWidget(self.comboBoxOrientation)
        self.verticalLayout_5.addLayout(self.verticalLayout_9)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.labelNewVersion = QtWidgets.QLabel(data)
        self.labelNewVersion.setText("")
        self.labelNewVersion.setObjectName("labelNewVersion")
        self.horizontalLayout_4.addWidget(self.labelNewVersion)
        self.verticalLayout_5.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.pushButtonScaleBarColor = QtWidgets.QPushButton(data)
        self.pushButtonScaleBarColor.setObjectName("pushButtonScaleBarColor")
        self.horizontalLayout_5.addWidget(self.pushButtonScaleBarColor)
        self.pushButtonScreenShot = QtWidgets.QPushButton(data)
        self.pushButtonScreenShot.setStyleSheet("border: none")
        self.pushButtonScreenShot.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/Camera_font_awesome.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButtonScreenShot.setIcon(icon)
        self.pushButtonScreenShot.setIconSize(QtCore.QSize(24, 24))
        self.pushButtonScreenShot.setObjectName("pushButtonScreenShot")
        self.horizontalLayout_5.addWidget(self.pushButtonScreenShot)
        self.verticalLayout_5.addLayout(self.horizontalLayout_5)
        self.horizontalLayout.addLayout(self.verticalLayout_5)
        self.layoutVolume.addLayout(self.horizontalLayout)
        self.line_5 = QtWidgets.QFrame(data)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.layoutVolume.addWidget(self.line_5)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.labelVolume = QtWidgets.QLabel(data)
        self.labelVolume.setStyleSheet("background-color:rgb(102, 95, 95);\n"
"padding: 3px;\n"
"color: rgb(223, 223, 223);")
        self.labelVolume.setObjectName("labelVolume")
        self.horizontalLayout_12.addWidget(self.labelVolume)
        self.layoutVolume.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.comboBoxVolume = QComboBoxIgnoreSCroll(data)
        self.comboBoxVolume.setObjectName("comboBoxVolume")
        self.horizontalLayout_2.addWidget(self.comboBoxVolume)
        self.pushButtonEditVolName = QtWidgets.QPushButton(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonEditVolName.sizePolicy().hasHeightForWidth())
        self.pushButtonEditVolName.setSizePolicy(sizePolicy)
        self.pushButtonEditVolName.setStyleSheet("border:none")
        self.pushButtonEditVolName.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButtonEditVolName.setIcon(icon1)
        self.pushButtonEditVolName.setIconSize(QtCore.QSize(20, 20))
        self.pushButtonEditVolName.setObjectName("pushButtonEditVolName")
        self.horizontalLayout_2.addWidget(self.pushButtonEditVolName)
        self.layoutVolume.addLayout(self.horizontalLayout_2)
        self.horizontalLayoutVol1Levels = QtWidgets.QHBoxLayout()
        self.horizontalLayoutVol1Levels.setObjectName("horizontalLayoutVol1Levels")
        self.comboBoxVolumeLut = QComboBoxIgnoreSCroll(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBoxVolumeLut.sizePolicy().hasHeightForWidth())
        self.comboBoxVolumeLut.setSizePolicy(sizePolicy)
        self.comboBoxVolumeLut.setObjectName("comboBoxVolumeLut")
        self.horizontalLayoutVol1Levels.addWidget(self.comboBoxVolumeLut)
        self.layoutVolume.addLayout(self.horizontalLayoutVol1Levels)
        self.verticalLayout.addLayout(self.layoutVolume)
        self.line = QtWidgets.QFrame(data)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout.addWidget(self.line)
        self.vol2Widget_layout = QtWidgets.QVBoxLayout()
        self.vol2Widget_layout.setObjectName("vol2Widget_layout")
        self.volume2Label_layout = QtWidgets.QHBoxLayout()
        self.volume2Label_layout.setObjectName("volume2Label_layout")
        self.checkBoxShowVol2Controls = QtWidgets.QCheckBox(data)
        self.checkBoxShowVol2Controls.setMaximumSize(QtCore.QSize(20, 16777215))
        self.checkBoxShowVol2Controls.setText("")
        self.checkBoxShowVol2Controls.setObjectName("checkBoxShowVol2Controls")
        self.volume2Label_layout.addWidget(self.checkBoxShowVol2Controls)
        self.label_14 = QtWidgets.QLabel(data)
        self.label_14.setStyleSheet("background-color:rgb(102, 95, 95);\n"
"padding: 3px;\n"
"color: rgb(223, 223, 223);")
        self.label_14.setObjectName("label_14")
        self.volume2Label_layout.addWidget(self.label_14)
        self.checkBoxVisibilityVol2 = QtWidgets.QCheckBox(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxVisibilityVol2.sizePolicy().hasHeightForWidth())
        self.checkBoxVisibilityVol2.setSizePolicy(sizePolicy)
        self.checkBoxVisibilityVol2.setText("")
        self.checkBoxVisibilityVol2.setChecked(True)
        self.checkBoxVisibilityVol2.setObjectName("checkBoxVisibilityVol2")
        self.volume2Label_layout.addWidget(self.checkBoxVisibilityVol2)
        self.vol2Widget_layout.addLayout(self.volume2Label_layout)
        self.vol2ControlsWidget = QtWidgets.QWidget(data)
        self.vol2ControlsWidget.setMinimumSize(QtCore.QSize(300, 80))
        self.vol2ControlsWidget.setObjectName("vol2ControlsWidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.vol2ControlsWidget)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.layoutVolume2 = QtWidgets.QVBoxLayout()
        self.layoutVolume2.setObjectName("layoutVolume2")
        self.comboBoxVolume2 = QtWidgets.QComboBox(self.vol2ControlsWidget)
        self.comboBoxVolume2.setObjectName("comboBoxVolume2")
        self.layoutVolume2.addWidget(self.comboBoxVolume2)
        self.horizontalLayoutVol2Levels = QtWidgets.QHBoxLayout()
        self.horizontalLayoutVol2Levels.setObjectName("horizontalLayoutVol2Levels")
        self.comboBoxVolumeLut2 = QtWidgets.QComboBox(self.vol2ControlsWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBoxVolumeLut2.sizePolicy().hasHeightForWidth())
        self.comboBoxVolumeLut2.setSizePolicy(sizePolicy)
        self.comboBoxVolumeLut2.setObjectName("comboBoxVolumeLut2")
        self.horizontalLayoutVol2Levels.addWidget(self.comboBoxVolumeLut2)
        self.doubleSpinBoxVol2Opacity = QtWidgets.QDoubleSpinBox(self.vol2ControlsWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBoxVol2Opacity.sizePolicy().hasHeightForWidth())
        self.doubleSpinBoxVol2Opacity.setSizePolicy(sizePolicy)
        self.doubleSpinBoxVol2Opacity.setObjectName("doubleSpinBoxVol2Opacity")
        self.horizontalLayoutVol2Levels.addWidget(self.doubleSpinBoxVol2Opacity)
        self.label_3 = QtWidgets.QLabel(self.vol2ControlsWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayoutVol2Levels.addWidget(self.label_3)
        self.layoutVolume2.addLayout(self.horizontalLayoutVol2Levels)
        self.verticalLayout_3.addLayout(self.layoutVolume2)
        self.vol2Widget_layout.addWidget(self.vol2ControlsWidget)
        self.verticalLayout.addLayout(self.vol2Widget_layout)
        self.line_2 = QtWidgets.QFrame(data)
        self.line_2.setLineWidth(5)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.checkBoxShowDataControls = QtWidgets.QCheckBox(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxShowDataControls.sizePolicy().hasHeightForWidth())
        self.checkBoxShowDataControls.setSizePolicy(sizePolicy)
        self.checkBoxShowDataControls.setText("")
        self.checkBoxShowDataControls.setObjectName("checkBoxShowDataControls")
        self.horizontalLayout_3.addWidget(self.checkBoxShowDataControls)
        self.labelData = QtWidgets.QLabel(data)
        self.labelData.setStyleSheet("background-color:rgb(102, 95, 95);\n"
"padding: 3px;\n"
"color: rgb(223, 223, 223);")
        self.labelData.setObjectName("labelData")
        self.horizontalLayout_3.addWidget(self.labelData)
        self.checkBoxVisibilityHeatmap = QtWidgets.QCheckBox(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxVisibilityHeatmap.sizePolicy().hasHeightForWidth())
        self.checkBoxVisibilityHeatmap.setSizePolicy(sizePolicy)
        self.checkBoxVisibilityHeatmap.setText("")
        self.checkBoxVisibilityHeatmap.setChecked(True)
        self.checkBoxVisibilityHeatmap.setObjectName("checkBoxVisibilityHeatmap")
        self.horizontalLayout_3.addWidget(self.checkBoxVisibilityHeatmap)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.dataWidget = QtWidgets.QWidget(data)
        self.dataWidget.setMinimumSize(QtCore.QSize(0, 170))
        self.dataWidget.setObjectName("dataWidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.dataWidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.comboBoxData = QtWidgets.QComboBox(self.dataWidget)
        self.comboBoxData.setObjectName("comboBoxData")
        self.verticalLayout_8.addWidget(self.comboBoxData)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.comboBoxLutHeatmap = QtWidgets.QComboBox(self.dataWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBoxLutHeatmap.sizePolicy().hasHeightForWidth())
        self.comboBoxLutHeatmap.setSizePolicy(sizePolicy)
        self.comboBoxLutHeatmap.setObjectName("comboBoxLutHeatmap")
        self.horizontalLayout_11.addWidget(self.comboBoxLutHeatmap)
        self.verticalLayout_8.addLayout(self.horizontalLayout_11)
        self.verticalLayout_4.addLayout(self.verticalLayout_8)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.doubleSpinBoxNegThresh = QtWidgets.QDoubleSpinBox(self.dataWidget)
        self.doubleSpinBoxNegThresh.setObjectName("doubleSpinBoxNegThresh")
        self.horizontalLayout_6.addWidget(self.doubleSpinBoxNegThresh)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem)
        self.pushButtonRecalcConnectComponents = QtWidgets.QPushButton(self.dataWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonRecalcConnectComponents.sizePolicy().hasHeightForWidth())
        self.pushButtonRecalcConnectComponents.setSizePolicy(sizePolicy)
        self.pushButtonRecalcConnectComponents.setObjectName("pushButtonRecalcConnectComponents")
        self.horizontalLayout_6.addWidget(self.pushButtonRecalcConnectComponents)
        self.doubleSpinBoxPosThresh = QtWidgets.QDoubleSpinBox(self.dataWidget)
        self.doubleSpinBoxPosThresh.setObjectName("doubleSpinBoxPosThresh")
        self.horizontalLayout_6.addWidget(self.doubleSpinBoxPosThresh)
        self.verticalLayout_4.addLayout(self.horizontalLayout_6)
        self.labelFdrThresholds = QtWidgets.QLabel(self.dataWidget)
        self.labelFdrThresholds.setObjectName("labelFdrThresholds")
        self.verticalLayout_4.addWidget(self.labelFdrThresholds)
        self.gridLayoutFdrButtons = QtWidgets.QGridLayout()
        self.gridLayoutFdrButtons.setObjectName("gridLayoutFdrButtons")
        self.verticalLayout_4.addLayout(self.gridLayoutFdrButtons)
        self.horizontalLayoutDataSliders = QtWidgets.QHBoxLayout()
        self.horizontalLayoutDataSliders.setObjectName("horizontalLayoutDataSliders")
        self.verticalLayout_4.addLayout(self.horizontalLayoutDataSliders)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem1)
        self.verticalLayout_4.addLayout(self.horizontalLayout_10)
        self.verticalLayoutConnectedComponents = QtWidgets.QHBoxLayout()
        self.verticalLayoutConnectedComponents.setObjectName("verticalLayoutConnectedComponents")
        self.verticalLayout_4.addLayout(self.verticalLayoutConnectedComponents)
        self.labelFdrThresholds.raise_()
        self.verticalLayout.addWidget(self.dataWidget)
        self.line_4 = QtWidgets.QFrame(data)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.verticalLayout.addWidget(self.line_4)
        self.verticalLayoutVectors = QtWidgets.QVBoxLayout()
        self.verticalLayoutVectors.setObjectName("verticalLayoutVectors")
        self.horizontalLayoutVectorHeader = QtWidgets.QHBoxLayout()
        self.horizontalLayoutVectorHeader.setObjectName("horizontalLayoutVectorHeader")
        self.checkBoxShowVectorControls = QtWidgets.QCheckBox(data)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxShowVectorControls.sizePolicy().hasHeightForWidth())
        self.checkBoxShowVectorControls.setSizePolicy(sizePolicy)
        self.checkBoxShowVectorControls.setText("")
        self.checkBoxShowVectorControls.setObjectName("checkBoxShowVectorControls")
        self.horizontalLayoutVectorHeader.addWidget(self.checkBoxShowVectorControls)
        self.label_9 = QtWidgets.QLabel(data)
        self.label_9.setStyleSheet("background-color:rgb(102, 95, 95);\n"
"padding: 3px;\n"
"color: rgb(223, 223, 223);")
        self.label_9.setObjectName("label_9")
        self.horizontalLayoutVectorHeader.addWidget(self.label_9)
        self.verticalLayoutVectors.addLayout(self.horizontalLayoutVectorHeader)
        self.vectorWidget = QtWidgets.QWidget(data)
        self.vectorWidget.setMinimumSize(QtCore.QSize(0, 100))
        self.vectorWidget.setObjectName("vectorWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.vectorWidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.comboBoxVectors = QtWidgets.QComboBox(self.vectorWidget)
        self.comboBoxVectors.setObjectName("comboBoxVectors")
        self.verticalLayout_2.addWidget(self.comboBoxVectors)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_10 = QtWidgets.QLabel(self.vectorWidget)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        self.spinBoxVectorSubsampling = QtWidgets.QSpinBox(self.vectorWidget)
        self.spinBoxVectorSubsampling.setObjectName("spinBoxVectorSubsampling")
        self.horizontalLayout_7.addWidget(self.spinBoxVectorSubsampling)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem2)
        self.label_11 = QtWidgets.QLabel(self.vectorWidget)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_7.addWidget(self.label_11)
        self.spinBoxVectorScale = QtWidgets.QSpinBox(self.vectorWidget)
        self.spinBoxVectorScale.setObjectName("spinBoxVectorScale")
        self.horizontalLayout_7.addWidget(self.spinBoxVectorScale)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem3)
        self.label_12 = QtWidgets.QLabel(self.vectorWidget)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_7.addWidget(self.label_12)
        self.pushButtonVectorColor = QtWidgets.QPushButton(self.vectorWidget)
        self.pushButtonVectorColor.setText("")
        self.pushButtonVectorColor.setObjectName("pushButtonVectorColor")
        self.horizontalLayout_7.addWidget(self.pushButtonVectorColor)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.pushButtonVectorMagnitudeFilter = QtWidgets.QPushButton(self.vectorWidget)
        self.pushButtonVectorMagnitudeFilter.setObjectName("pushButtonVectorMagnitudeFilter")
        self.verticalLayout_2.addWidget(self.pushButtonVectorMagnitudeFilter)
        self.horizontalLayoutMagnitudeSlider = QtWidgets.QHBoxLayout()
        self.horizontalLayoutMagnitudeSlider.setObjectName("horizontalLayoutMagnitudeSlider")
        self.verticalLayout_2.addLayout(self.horizontalLayoutMagnitudeSlider)
        self.verticalLayoutVectors.addWidget(self.vectorWidget)
        self.verticalLayout.addLayout(self.verticalLayoutVectors)
        self.line_3 = QtWidgets.QFrame(data)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout.addWidget(self.line_3)
        self.gridLayoutScalebar = QtWidgets.QGridLayout()
        self.gridLayoutScalebar.setObjectName("gridLayoutScalebar")
        self.doubleSpinBoxVoxelSize = QtWidgets.QDoubleSpinBox(data)
        self.doubleSpinBoxVoxelSize.setObjectName("doubleSpinBoxVoxelSize")
        self.gridLayoutScalebar.addWidget(self.doubleSpinBoxVoxelSize, 0, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(data)
        self.label_15.setObjectName("label_15")
        self.gridLayoutScalebar.addWidget(self.label_15, 0, 0, 1, 1)
        self.doubleSpinBoxScaleBarLength = QtWidgets.QDoubleSpinBox(data)
        self.doubleSpinBoxScaleBarLength.setObjectName("doubleSpinBoxScaleBarLength")
        self.gridLayoutScalebar.addWidget(self.doubleSpinBoxScaleBarLength, 0, 4, 1, 1)
        self.label_16 = QtWidgets.QLabel(data)
        self.label_16.setObjectName("label_16")
        self.gridLayoutScalebar.addWidget(self.label_16, 0, 3, 1, 1)
        self.checkBoxScaleBarLabel = QtWidgets.QCheckBox(data)
        self.checkBoxScaleBarLabel.setObjectName("checkBoxScaleBarLabel")
        self.gridLayoutScalebar.addWidget(self.checkBoxScaleBarLabel, 0, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayoutScalebar)
        self.line_9 = QtWidgets.QFrame(data)
        self.line_9.setLineWidth(4)
        self.line_9.setMidLineWidth(2)
        self.line_9.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_9.setObjectName("line_9")
        self.verticalLayout.addWidget(self.line_9)
        self.verticalLayoutColorScale = QtWidgets.QVBoxLayout()
        self.verticalLayoutColorScale.setObjectName("verticalLayoutColorScale")
        self.verticalLayout.addLayout(self.verticalLayoutColorScale)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem4)

        self.retranslateUi(data)
        QtCore.QMetaObject.connectSlotsByName(data)

    def retranslateUi(self, data):
        _translate = QtCore.QCoreApplication.translate
        data.setWindowTitle(_translate("data", "Form"))
        self.label_13.setText(_translate("data", "Viewport visiblity"))
        self.label.setText(_translate("data", "Edit viewport"))
        self.checkBoxLinkViews.setText(_translate("data", "Link views"))
        self.checkBox6Views.setText(_translate("data", "Two row view"))
        self.label_2.setText(_translate("data", "Orientation"))
        self.comboBoxOrientation.setItemText(0, _translate("data", "sagittal"))
        self.comboBoxOrientation.setItemText(1, _translate("data", "coronal"))
        self.comboBoxOrientation.setItemText(2, _translate("data", "axial"))
        self.comboBoxOrientation.setItemText(3, _translate("data", "Isosurface - Not implemented"))
        self.pushButtonScaleBarColor.setText(_translate("data", "scale bar color"))
        self.labelVolume.setText(_translate("data", "Volume 1"))
        self.label_14.setText(_translate("data", "Volume 2"))
        self.label_3.setText(_translate("data", "opacity"))
        self.labelData.setText(_translate("data", "Heatmap Data"))
        self.pushButtonRecalcConnectComponents.setText(_translate("data", "Find blobs"))
        self.labelFdrThresholds.setText(_translate("data", "FDR thresholds"))
        self.label_9.setText(_translate("data", "Vectors"))
        self.label_10.setText(_translate("data", "Subsample"))
        self.label_11.setText(_translate("data", "Scale"))
        self.label_12.setText(_translate("data", "Arrow colour"))
        self.pushButtonVectorMagnitudeFilter.setText(_translate("data", "filter magnitude"))
        self.label_15.setText(_translate("data", "Voxel size"))
        self.label_16.setText(_translate("data", "Scale bar length"))
        self.checkBoxScaleBarLabel.setText(_translate("data", "scale label"))
from vpv.ui.views.combobox_ignore_scroll import QComboBoxIgnoreSCroll
from . import resources_rc
