# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_annotations.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Annotations(object):
    def setupUi(self, Annotations):
        Annotations.setObjectName("Annotations")
        Annotations.resize(700, 901)
        Annotations.setMinimumSize(QtCore.QSize(0, 40))
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(Annotations)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.tabWidgetOptions = QtWidgets.QTabWidget(Annotations)
        self.tabWidgetOptions.setTabPosition(QtWidgets.QTabWidget.North)
        self.tabWidgetOptions.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidgetOptions.setObjectName("tabWidgetOptions")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.comboBoxAnnotationsVolumes = QtWidgets.QComboBox(self.tab_3)
        self.comboBoxAnnotationsVolumes.setObjectName("comboBoxAnnotationsVolumes")
        self.verticalLayout.addWidget(self.comboBoxAnnotationsVolumes)
        self.line_6 = QtWidgets.QFrame(self.tab_3)
        self.line_6.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.verticalLayout.addWidget(self.line_6)
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.pushButtonSaveAnnotations = QtWidgets.QPushButton(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonSaveAnnotations.sizePolicy().hasHeightForWidth())
        self.pushButtonSaveAnnotations.setSizePolicy(sizePolicy)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButtonSaveAnnotations.setIcon(icon)
        self.pushButtonSaveAnnotations.setIconSize(QtCore.QSize(32, 32))
        self.pushButtonSaveAnnotations.setObjectName("pushButtonSaveAnnotations")
        self.horizontalLayout_20.addWidget(self.pushButtonSaveAnnotations)
        self.line_5 = QtWidgets.QFrame(self.tab_3)
        self.line_5.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.horizontalLayout_20.addWidget(self.line_5)
        self.label_2 = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_20.addWidget(self.label_2)
        self.spinBoxAnnotationCircleSize = QtWidgets.QSpinBox(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBoxAnnotationCircleSize.sizePolicy().hasHeightForWidth())
        self.spinBoxAnnotationCircleSize.setSizePolicy(sizePolicy)
        self.spinBoxAnnotationCircleSize.setProperty("value", 10)
        self.spinBoxAnnotationCircleSize.setObjectName("spinBoxAnnotationCircleSize")
        self.horizontalLayout_20.addWidget(self.spinBoxAnnotationCircleSize)
        self.line_7 = QtWidgets.QFrame(self.tab_3)
        self.line_7.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_7.setObjectName("line_7")
        self.horizontalLayout_20.addWidget(self.line_7)
        self.label_6 = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_6.sizePolicy().hasHeightForWidth())
        self.label_6.setSizePolicy(sizePolicy)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_20.addWidget(self.label_6)
        self.labelXPos = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelXPos.sizePolicy().hasHeightForWidth())
        self.labelXPos.setSizePolicy(sizePolicy)
        self.labelXPos.setMaximumSize(QtCore.QSize(20, 16777215))
        self.labelXPos.setObjectName("labelXPos")
        self.horizontalLayout_20.addWidget(self.labelXPos)
        self.label_35 = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_35.sizePolicy().hasHeightForWidth())
        self.label_35.setSizePolicy(sizePolicy)
        self.label_35.setObjectName("label_35")
        self.horizontalLayout_20.addWidget(self.label_35)
        self.labelYPos = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelYPos.sizePolicy().hasHeightForWidth())
        self.labelYPos.setSizePolicy(sizePolicy)
        self.labelYPos.setObjectName("labelYPos")
        self.horizontalLayout_20.addWidget(self.labelYPos)
        self.label_36 = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_36.sizePolicy().hasHeightForWidth())
        self.label_36.setSizePolicy(sizePolicy)
        self.label_36.setObjectName("label_36")
        self.horizontalLayout_20.addWidget(self.label_36)
        self.labelZPos = QtWidgets.QLabel(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelZPos.sizePolicy().hasHeightForWidth())
        self.labelZPos.setSizePolicy(sizePolicy)
        self.labelZPos.setObjectName("labelZPos")
        self.horizontalLayout_20.addWidget(self.labelZPos)
        self.verticalLayout.addLayout(self.horizontalLayout_20)
        self.line_3 = QtWidgets.QFrame(self.tab_3)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout.addWidget(self.line_3)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.line = QtWidgets.QFrame(self.tab_3)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_4.addWidget(self.line)
        self.treeWidgetAvailableTerms = QtWidgets.QTreeWidget(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.treeWidgetAvailableTerms.sizePolicy().hasHeightForWidth())
        self.treeWidgetAvailableTerms.setSizePolicy(sizePolicy)
        self.treeWidgetAvailableTerms.setMinimumSize(QtCore.QSize(0, 300))
        self.treeWidgetAvailableTerms.setObjectName("treeWidgetAvailableTerms")
        self.treeWidgetAvailableTerms.headerItem().setText(0, "1")
        self.horizontalLayout_4.addWidget(self.treeWidgetAvailableTerms)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.textEditAnnotationInfo = QtWidgets.QTextEdit(self.tab_3)
        self.textEditAnnotationInfo.setMaximumSize(QtCore.QSize(16777215, 100))
        self.textEditAnnotationInfo.setObjectName("textEditAnnotationInfo")
        self.verticalLayout.addWidget(self.textEditAnnotationInfo)
        self.line_2 = QtWidgets.QFrame(self.tab_3)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout.addWidget(self.line_2)
        self.horizontalLayout.addLayout(self.verticalLayout)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/pencil.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabWidgetOptions.addTab(self.tab_3, icon1, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.layoutWidget = QtWidgets.QWidget(self.tab_4)
        self.layoutWidget.setGeometry(QtCore.QRect(41, 31, 197, 89))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_4 = QtWidgets.QLabel(self.layoutWidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 0, 0, 1, 1)
        self.lineEditCentre = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEditCentre.setObjectName("lineEditCentre")
        self.gridLayout_2.addWidget(self.lineEditCentre, 0, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 1, 0, 1, 1)
        self.lineEditStage = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEditStage.setObjectName("lineEditStage")
        self.gridLayout_2.addWidget(self.lineEditStage, 1, 1, 1, 1)
        self.lineEditModality = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEditModality.setObjectName("lineEditModality")
        self.gridLayout_2.addWidget(self.lineEditModality, 2, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.layoutWidget)
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 2, 0, 1, 1)
        self.layoutWidget1 = QtWidgets.QWidget(self.tab_4)
        self.layoutWidget1.setGeometry(QtCore.QRect(40, 120, 280, 59))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.gridLayout = QtWidgets.QGridLayout(self.layoutWidget1)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget1)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.lineEditAnnotatorId = QtWidgets.QLineEdit(self.layoutWidget1)
        self.lineEditAnnotatorId.setObjectName("lineEditAnnotatorId")
        self.gridLayout.addWidget(self.lineEditAnnotatorId, 0, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.dateEdit = QtWidgets.QDateEdit(self.layoutWidget1)
        self.dateEdit.setObjectName("dateEdit")
        self.gridLayout.addWidget(self.dateEdit, 1, 1, 1, 1)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/settings.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabWidgetOptions.addTab(self.tab_4, icon2, "")
        self.verticalLayout_17.addWidget(self.tabWidgetOptions)

        self.retranslateUi(Annotations)
        self.tabWidgetOptions.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(Annotations)

    def retranslateUi(self, Annotations):
        _translate = QtCore.QCoreApplication.translate
        Annotations.setWindowTitle(_translate("Annotations", "Form"))
        self.pushButtonSaveAnnotations.setToolTip(_translate("Annotations", "Save annotation as xml"))
        self.pushButtonSaveAnnotations.setText(_translate("Annotations", "Save annotations"))
        self.label_2.setText(_translate("Annotations", "Circle radius"))
        self.spinBoxAnnotationCircleSize.setToolTip(_translate("Annotations", "radius of the marker"))
        self.label_6.setText(_translate("Annotations", "x:"))
        self.labelXPos.setText(_translate("Annotations", "0"))
        self.label_35.setText(_translate("Annotations", "Y:"))
        self.labelYPos.setText(_translate("Annotations", "0"))
        self.label_36.setText(_translate("Annotations", "Z:"))
        self.labelZPos.setText(_translate("Annotations", "0"))
        self.label_4.setText(_translate("Annotations", "Centre"))
        self.label_5.setText(_translate("Annotations", "Stage"))
        self.label_7.setText(_translate("Annotations", "Modality"))
        self.label.setText(_translate("Annotations", "Annotator ID"))
        self.label_3.setText(_translate("Annotations", "Date of annotation"))


from . import resources_rc
