# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_importer.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(967, 507)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        Dialog.setMinimumSize(QtCore.QSize(500, 130))
        self.gridLayout_2 = QtWidgets.QGridLayout(Dialog)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.table = QtWidgets.QTableWidget(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.table.sizePolicy().hasHeightForWidth())
        self.table.setSizePolicy(sizePolicy)
        self.table.setLineWidth(2)
        self.table.setMidLineWidth(1)
        self.table.setColumnCount(3)
        self.table.setObjectName("table")
        self.table.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.table.setHorizontalHeaderItem(2, item)
        self.gridLayout_2.addWidget(self.table, 4, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButtonChooseFile = QtWidgets.QPushButton(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonChooseFile.sizePolicy().hasHeightForWidth())
        self.pushButtonChooseFile.setSizePolicy(sizePolicy)
        self.pushButtonChooseFile.setObjectName("pushButtonChooseFile")
        self.horizontalLayout.addWidget(self.pushButtonChooseFile)
        self.pushButtonChoseDir = QtWidgets.QPushButton(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonChoseDir.sizePolicy().hasHeightForWidth())
        self.pushButtonChoseDir.setSizePolicy(sizePolicy)
        self.pushButtonChoseDir.setObjectName("pushButtonChoseDir")
        self.horizontalLayout.addWidget(self.pushButtonChoseDir)
        self.checkBoxMemoryMap = QtWidgets.QCheckBox(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxMemoryMap.sizePolicy().hasHeightForWidth())
        self.checkBoxMemoryMap.setSizePolicy(sizePolicy)
        self.checkBoxMemoryMap.setChecked(False)
        self.checkBoxMemoryMap.setObjectName("checkBoxMemoryMap")
        self.horizontalLayout.addWidget(self.checkBoxMemoryMap)
        self.checkBoxAllSameType = QtWidgets.QCheckBox(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxAllSameType.sizePolicy().hasHeightForWidth())
        self.checkBoxAllSameType.setSizePolicy(sizePolicy)
        self.checkBoxAllSameType.setObjectName("checkBoxAllSameType")
        self.horizontalLayout.addWidget(self.checkBoxAllSameType)
        self.checkBoxDistrbute = QtWidgets.QCheckBox(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBoxDistrbute.sizePolicy().hasHeightForWidth())
        self.checkBoxDistrbute.setSizePolicy(sizePolicy)
        self.checkBoxDistrbute.setObjectName("checkBoxDistrbute")
        self.horizontalLayout.addWidget(self.checkBoxDistrbute)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.gridLayout_2.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        self.verticalLayoutVirtualStack = QtWidgets.QVBoxLayout()
        self.verticalLayoutVirtualStack.setObjectName("verticalLayoutVirtualStack")
        self.virtualStackWidget = QtWidgets.QWidget(Dialog)
        self.virtualStackWidget.setMinimumSize(QtCore.QSize(0, 130))
        self.virtualStackWidget.setObjectName("virtualStackWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.virtualStackWidget)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.virtualStackWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.lineEditFileNameContains = QtWidgets.QLineEdit(self.virtualStackWidget)
        self.lineEditFileNameContains.setObjectName("lineEditFileNameContains")
        self.gridLayout.addWidget(self.lineEditFileNameContains, 0, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.virtualStackWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.lineEditFileNameDoesNotContain = QtWidgets.QLineEdit(self.virtualStackWidget)
        self.lineEditFileNameDoesNotContain.setObjectName("lineEditFileNameDoesNotContain")
        self.gridLayout.addWidget(self.lineEditFileNameDoesNotContain, 1, 1, 1, 1)
        self.pushButtonFilter = QtWidgets.QPushButton(self.virtualStackWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonFilter.sizePolicy().hasHeightForWidth())
        self.pushButtonFilter.setSizePolicy(sizePolicy)
        self.pushButtonFilter.setObjectName("pushButtonFilter")
        self.gridLayout.addWidget(self.pushButtonFilter, 3, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_4 = QtWidgets.QLabel(self.virtualStackWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.labelNumberOfFiles = QtWidgets.QLabel(self.virtualStackWidget)
        self.labelNumberOfFiles.setText("")
        self.labelNumberOfFiles.setObjectName("labelNumberOfFiles")
        self.horizontalLayout_3.addWidget(self.labelNumberOfFiles)
        self.gridLayout.addLayout(self.horizontalLayout_3, 3, 1, 1, 1)
        self.verticalLayoutVirtualStack.addWidget(self.virtualStackWidget)
        self.gridLayout_2.addLayout(self.verticalLayoutVirtualStack, 2, 0, 1, 1)
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_2.addWidget(self.line_2, 3, 0, 1, 1)
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_2.addWidget(self.line, 5, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.pushButtonOK = QtWidgets.QPushButton(Dialog)
        self.pushButtonOK.setObjectName("pushButtonOK")
        self.horizontalLayout_2.addWidget(self.pushButtonOK)
        self.pushButtonCancel = QtWidgets.QPushButton(Dialog)
        self.pushButtonCancel.setObjectName("pushButtonCancel")
        self.horizontalLayout_2.addWidget(self.pushButtonCancel)
        self.gridLayout_2.addLayout(self.horizontalLayout_2, 6, 0, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_3 = QtWidgets.QLabel(Dialog)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_4.addWidget(self.label_3)
        self.lineEditFolderFilter = QtWidgets.QLineEdit(Dialog)
        self.lineEditFolderFilter.setObjectName("lineEditFolderFilter")
        self.horizontalLayout_4.addWidget(self.lineEditFolderFilter)
        self.gridLayout_2.addLayout(self.horizontalLayout_4, 1, 0, 1, 1)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        item = self.table.horizontalHeaderItem(0)
        item.setText(_translate("Dialog", "Data"))
        item = self.table.horizontalHeaderItem(1)
        item.setText(_translate("Dialog", "Type"))
        item = self.table.horizontalHeaderItem(2)
        item.setText(_translate("Dialog", "Load?"))
        self.pushButtonChooseFile.setText(_translate("Dialog", "Choose files"))
        self.pushButtonChoseDir.setText(_translate("Dialog", "Load stack of 2D slices"))
        self.checkBoxMemoryMap.setText(_translate("Dialog", "memory map volumes"))
        self.checkBoxAllSameType.setText(_translate("Dialog", "All same type?"))
        self.checkBoxDistrbute.setText(_translate("Dialog", "distribute across views"))
        self.label.setText(_translate("Dialog", "Filename contains (eg:.   .tiff)"))
        self.label_2.setText(_translate("Dialog", "Filename does not contain (eg: spr.tif, rec.tif)"))
        self.pushButtonFilter.setText(_translate("Dialog", "Filter"))
        self.label_4.setText(_translate("Dialog", "Number of files:"))
        self.pushButtonOK.setText(_translate("Dialog", "OK"))
        self.pushButtonCancel.setText(_translate("Dialog", "Cancel"))
        self.label_3.setToolTip(_translate("Dialog", "<html><head/><body><p>Filter volumes using wildcard patterns..</p><p><br/></p><p>For example if you have data structure like this</p><p><br/></p><p>root_dir</p><p>    - mutant_1</p><p>        - registration</p><p>             - images</p><p>             - deformations</p><p>        - other</p><p>    - mutant_2</p><p>        - registration</p><p>             - images</p><p>             - deformations</p><p>        - other</p><p>Using the following pattern would load volumes from the registration/images subfolders only</p><p><br/></p><p><span style=\" font-style:italic;\">*reg*image*</span></p></body></html>"))
        self.label_3.setText(_translate("Dialog", "filter"))
        self.lineEditFolderFilter.setToolTip(_translate("Dialog", "<html><head/><body><p>Enter a search pattern (wuth wild cards *) to filter input images by.</p><p>For example, using pattern \'reg*rig\' would find all images that had prent folderds named registrations/rigid</p></body></html>"))


