__version__ = '2.2.5'  # Add new annotation procedures for EOL and EML
# __version__ = '2.2.4'  # Add new annotation procedures for EOL and EML
#__version__ = '2.2.3' # Bugfix - prolems with incorrect mouse hover voxel value reporting
#__version__ = '2.2.2' # Added anatomical orientation indicators
# __version__ = '2.2.1' # Moved to default RAS format. RAS volumes should look the same as in Slicer
#__version__ = '2.2.0' # Moved to default RAS format. RAS volumes should look the same as in Slicer
# __version__ = '2.1.0' # Added some checks to the annotation module. Add log viewer
#__version__ = '2.0.2' # Made changes to Jax and HAr annotation lists. Fixed the clear function a bit
#__version__ = '2.0.1' # Fixed done checkboxes loading and addict import issue
# __version__ = '2.0.0' #Lots of annotations changes
#__version__ = '1.9.2'  # Some bug fixes
#__version__ = '1.9.1' # Added arbitrary flips and fgixed a bunch of bugs
#__version__ = '1.9.0' # Added impc flip button made some bodges to get vews annotations etc in correct orientation
# __version__ = '1.8.3' # Slice synchroisation Bug fixes
#__version__ = '1.8.1' # Ported to Qt5 to take advantage of high res monitor scaling
#__version__ = '1.8.0' # Rleased juut before Christmas 2017
